Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(539)

Unified Diff: webrtc/modules/video_coding/codecs/test/plot_videoprocessor_integrationtest.cc

Issue 2703333004: Rename config structs in VideoProcessor tests. (Closed)
Patch Set: sprang comments 1. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | webrtc/modules/video_coding/codecs/test/videoprocessor_integrationtest.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/modules/video_coding/codecs/test/plot_videoprocessor_integrationtest.cc
diff --git a/webrtc/modules/video_coding/codecs/test/plot_videoprocessor_integrationtest.cc b/webrtc/modules/video_coding/codecs/test/plot_videoprocessor_integrationtest.cc
index d82169b6c1dc341dc4bb8905764ffae3351f9a70..668867010a54aed804d9f304ba0dab7b3ecce2d2 100644
--- a/webrtc/modules/video_coding/codecs/test/plot_videoprocessor_integrationtest.cc
+++ b/webrtc/modules/video_coding/codecs/test/plot_videoprocessor_integrationtest.cc
@@ -53,36 +53,36 @@ class PlotVideoProcessorIntegrationTest
void RunTest(int width, int height, const std::string& filename) {
// Bitrate and frame rate profile.
RateProfile rate_profile;
- SetRateProfilePars(&rate_profile,
- 0, // update_index
- bitrate_, framerate_,
- 0); // frame_index_rate_update
+ SetRateProfile(&rate_profile,
+ 0, // update_index
+ bitrate_, framerate_,
+ 0); // frame_index_rate_update
rate_profile.frame_index_rate_update[1] = kNumFramesLong + 1;
rate_profile.num_frames = kNumFramesLong;
// Codec/network settings.
- CodecConfigPars process_settings;
- SetCodecParameters(
- &process_settings, codec_type_, kHwCodec, kUseSingleCore, kPacketLoss,
- -1, // key_frame_interval
- 1, // num_temporal_layers
- kErrorConcealmentOn, kDenoisingOn, kFrameDropperOn, kSpatialResizeOn,
- width, height, filename, kVerboseLogging);
- // Metrics for expected quality (PSNR avg, PSNR min, SSIM avg, SSIM min).
- QualityMetrics quality_metrics;
- SetQualityMetrics(&quality_metrics, 15.0, 10.0, 0.2, 0.1);
- // Metrics for rate control.
- RateControlMetrics rc_metrics[1];
- SetRateControlMetrics(rc_metrics,
- 0, // update_index
- 300, // max_num_dropped_frames,
- 400, // max_key_frame_size_mismatch
- 200, // max_delta_frame_size_mismatch
- 100, // max_encoding_rate_mismatch
- 300, // max_time_hit_target
- 0, // num_spatial_resizes
- 1); // num_key_frames
- ProcessFramesAndVerify(quality_metrics, rate_profile, process_settings,
- rc_metrics, &kVisualizationParams);
+ CodecParams process_settings;
+ SetCodecParams(&process_settings, codec_type_, kHwCodec, kUseSingleCore,
+ kPacketLoss,
+ -1, // key_frame_interval
+ 1, // num_temporal_layers
+ kErrorConcealmentOn, kDenoisingOn, kFrameDropperOn,
+ kSpatialResizeOn, width, height, filename, kVerboseLogging);
+ // Thresholds for expected quality (PSNR avg, PSNR min, SSIM avg, SSIM min).
+ QualityThresholds quality_thresholds;
+ SetQualityThresholds(&quality_thresholds, 15.0, 10.0, 0.2, 0.1);
+ // Thresholds for rate control.
+ RateControlThresholds rc_thresholds[1];
+ SetRateControlThresholds(rc_thresholds,
+ 0, // update_index
+ 300, // max_num_dropped_frames,
+ 400, // max_key_frame_size_mismatch
+ 200, // max_delta_frame_size_mismatch
+ 100, // max_encoding_rate_mismatch
+ 300, // max_time_hit_target
+ 0, // num_spatial_resizes
+ 1); // num_key_frames
+ ProcessFramesAndVerify(quality_thresholds, rate_profile, process_settings,
+ rc_thresholds, &kVisualizationParams);
}
const int bitrate_;
const int framerate_;
« no previous file with comments | « no previous file | webrtc/modules/video_coding/codecs/test/videoprocessor_integrationtest.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698